==========
Changelog
==========

This project adheres to `Semantic Versioning <https://semver.org/>`_.

0.4.0 (2021-02-21)
-----------------------

* `ArcheApiClient.get_resource(res_uri)` method added to the complete graph of an ARCHE-URI
* `ArcheApiClient.write_resource_to_file(res_uri, format='ttl')` method added to writa a complete graph of an ARCHE-URI to file

0.3.0 (2021-02-20)
-----------------------

* `ArcheApiClient.top_col_ids()` method added to fetch all TopCollection URIs and Lables


0.1.0 (2021-02-19)
-----------------------

**Added**

* Created the project using cookietemple version 1.2.4

**Fixed**

**Dependencies**

**Deprecated**
